using ldap_cesi.DTOs.Inputs;
using ldap_cesi.Services.Interfaces;
using Microsoft.AspNetCore.Mvc;

namespace ldap_cesi.Controllers;
[ApiController]
[Route("api/utilisateur")]
public class UtilisateurController : ControllerBase
{
    private IUtilisateurService _utilisateurService;

    public UtilisateurController(IUtilisateurService utilisateurService)
    {
        _utilisateurService = utilisateurService;
    }
    
    [HttpPost("login")]
    public async Task<IActionResult> Login([FromBody] UtilisateurLoginDto utilisateurInput)
    {
        var response = await _utilisateurService.Login(utilisateurInput);
        return StatusCode(response.StatusCode, response);
    }
    
    // GET: api/utilisateurs
    /// <summary>
    /// Endpoint qui retournes tous les utilisateurs
    /// </summary>
    /// <returns>List<Utilisateur></returns>
    [HttpGet]
    public async Task<ActionResult> GetUtilisateurs()
    {
        var result = await _utilisateurService.GetAll();
        return result.Success ? Ok(result) : BadRequest(result);
    }            
    
    // GET: api/utilisateur
    /// <summary>
    /// Endpoint retourne l'utilisateur correspondant à l'id en param
    /// </summary>
    /// <returns>Utilisateur</returns>
    [HttpGet("{id}")]
    public async Task<ActionResult> GetUtilisateurById(int id)
    {
        var result = await _utilisateurService.GetById(id);
        return result.Success ? Ok(result) : BadRequest(result);
    }
}